@@ -168,11 +168,11 @@ function saveSettings() {
 	
 		while (e.hasMoreElements()) {
 			win = e.getNext();
-			win.db_readPrefs();
-			win.db_setStyles();
-			win.db_populateDownloads();
-			//win.db_startInProgress();
-			win.db_checkMiniMode();
+			win._dlbar_readPrefs();
+			win._dlbar_setStyles();
+			win._dlbar_populateDownloads();
+			//win._dlbar_startInProgress();
+			win._dlbar_checkMiniMode();
 		}
 	} catch (e){}
 
