@@ -7,6 +7,8 @@ Downbar.prototype = {
 	classID: Components.ID("{D4EE4143-3560-44c3-B170-4AC54D7D8AC1}"),
 	contractID: "@devonjensen.com/downbar/downbar;1",
 	classDescription: "Window independent Download Statusbar functions",
+	
+	_xpcom_categories: [{ category: "xpcom-startup", service: true }],
 
 	QueryInterface: function(aIID) {
 		if(!aIID.equals(CI.nsISupports) && !aIID.equals(CI.nsIObserver) && !aIID.equals(CI.nsISupportsWeakReference)) // you can claim you implement more interfaces here
@@ -34,16 +36,9 @@ Downbar.prototype = {
 					
 					var obsSvc = CC["@mozilla.org/observer-service;1"].getService(CI.nsIObserverService);
 					obsSvc.addObserver(this, "profile-after-change", true);
-					obsSvc.addObserver(this, "quit-application-granted", true);
+					
 					//obsSvc.addObserver(this, "quit-application-requested", true);
-					//obsSvc.addObserver(this, "dl-start", true);
-					//obsSvc.addObserver(this, "dl-done", true);
-					obsSvc.addObserver(this, "em-action-requested", true);
 					//obsSvc.addObserver(this, "domwindowopened", true);
-					obsSvc.addObserver(this, "download-manager-remove-download", true);
-					// "dl-scanning"
-					// "dl-failed"
-					// "dl-blocked"
 				//}
 
 			break;
@@ -54,12 +49,27 @@ Downbar.prototype = {
 		
 			case "profile-after-change":
 				// This happens after profile has been loaded and user preferences have been read.
-				// startup code here	
-							
-				var db_dlmgrContractID = "@mozilla.org/download-manager;1";
-				var db_dlmgrIID = Components.interfaces.nsIDownloadManager;
-				var db_gDownloadManager = Components.classes[db_dlmgrContractID].getService(db_dlmgrIID);
-				db_gDownloadManager.addListener(this);
+				// startup code here
+					
+				var _dlbar_dlmgrContractID = "@mozilla.org/download-manager;1";
+				var _dlbar_dlmgrIID = Components.interfaces.nsIDownloadManager;
+				var _dlbar_gDownloadManager = Components.classes[_dlbar_dlmgrContractID].getService(_dlbar_dlmgrIID);
+				_dlbar_gDownloadManager.addListener(this);
+				
+				var obsSvc = CC["@mozilla.org/observer-service;1"].getService(CI.nsIObserverService);
+				obsSvc.addObserver(this, "quit-application-granted", true);
+				obsSvc.addObserver(this, "em-action-requested", true);
+				obsSvc.addObserver(this, "download-manager-remove-download", true);
+						
+				//try {
+					//Components.utils.import("resource://gre/modules/AddonManager.jsm");
+		
+					//AddonManager.addAddonListener(_dlbar_uninstallListen);
+					//getAddonByID("{D4DD63FA-01E4-46a7-B6B1-EDAB7D6AD389}", function(addon) {
+					//	document.getElementById("extVersion").value = addon.version;
+					//}
+				//}
+				//catch(e){}
 				
 			break;
 			
@@ -68,17 +78,17 @@ Downbar.prototype = {
 			// Firefox 3 broke this - closing a browser window with the X works, but File..Exit doesn't,
 			//    so now using the unload event of browser windows, which works with both - downbarClose()
 			/*
-				var db_pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
+				var _dlbar_pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
 				try {
-					var launchDLWin = db_pref.getBoolPref("downbar.function.launchOnClose");
+					var launchDLWin = _dlbar_pref.getBoolPref("downbar.function.launchOnClose");
 				} catch(e){}
 				
-				var db_dlmgrContractID = "@mozilla.org/download-manager;1";
-				var db_dlmgrIID = Components.interfaces.nsIDownloadManager;
-				db_gDownloadManager = Components.classes[db_dlmgrContractID].getService(db_dlmgrIID);		
+				var _dlbar_dlmgrContractID = "@mozilla.org/download-manager;1";
+				var _dlbar_dlmgrIID = Components.interfaces.nsIDownloadManager;
+				_dlbar_gDownloadManager = Components.classes[_dlbar_dlmgrContractID].getService(_dlbar_dlmgrIID);		
 					
 				// xxx paused downloads are included in activeDownloadCount, should I ignore paused downloads?
-				if(launchDLWin && db_gDownloadManager.activeDownloadCount > 0) {
+				if(launchDLWin && _dlbar_gDownloadManager.activeDownloadCount > 0) {
 					
 					// This cancels the quit process - see globalOverlay.js
 					//try {
@@ -94,16 +104,16 @@ Downbar.prototype = {
 			
 			case "quit-application-granted":
 				
-				var db_pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
+				var _dlbar_pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
 				try {
-					if(db_pref.getBoolPref("downbar.toUninstall")) {
+					if(_dlbar_pref.getBoolPref("downbar.toUninstall")) {
 						// Put back the firefox download manager settings
-						db_pref.setBoolPref("browser.download.manager.showWhenStarting", true);
-						db_pref.setBoolPref("browser.download.manager.showAlertOnComplete", true);
-						db_pref.setBoolPref("downbar.toUninstall", false);
-						db_pref.setBoolPref("downbar.function.firstRun", true);
-						if(!db_pref.getBoolPref("downbar.function.keepHistory"))
-							db_pref.setIntPref("browser.download.manager.retention", 0);
+						_dlbar_pref.setBoolPref("browser.download.manager.showWhenStarting", true);
+						_dlbar_pref.setBoolPref("browser.download.manager.showAlertOnComplete", true);
+						_dlbar_pref.setBoolPref("downbar.toUninstall", false);
+						_dlbar_pref.setBoolPref("downbar.function.firstRun", true);
+						if(!_dlbar_pref.getBoolPref("downbar.function.keepHistory"))
+							_dlbar_pref.setIntPref("browser.download.manager.retention", 0);
 							
 						// xxx Remove DownbarShow column from download database? it takes a lot of code, dropping and copying entire tables, prob not worth it
 												
@@ -111,28 +121,29 @@ Downbar.prototype = {
 				} catch(e){}
 				
 				try {
-					var clearOnClose = db_pref.getBoolPref("downbar.function.clearOnClose");
+					var clearOnClose = _dlbar_pref.getBoolPref("downbar.function.clearOnClose");
 				} catch(e){}
 				
-				this.db_trimHistory();
+				this._dlbar_trimHistory();
 				
 				if(clearOnClose) {
-					this.db_clearAllFinished();
+					this._dlbar_clearAllFinished();
 				}
 				
 		
 			break;
 			
 			case "em-action-requested":
+						
 				subject = aSubject.QueryInterface(Components.interfaces.nsIUpdateItem);
 				if (subject.id == "{D4DD63FA-01E4-46a7-B6B1-EDAB7D6AD389}") {
-					var db_pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
+					var _dlbar_pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
 					switch (aData) {
 		    			case "item-uninstalled":
-		     				db_pref.setBoolPref("downbar.toUninstall", true);
+		     				_dlbar_pref.setBoolPref("downbar.toUninstall", true);
 		    				break;
 		    			case "item-cancel-action":
-		     				db_pref.setBoolPref("downbar.toUninstall", false);
+		     				_dlbar_pref.setBoolPref("downbar.toUninstall", false);
 		    				break;
 		    		}
 					
@@ -149,7 +160,7 @@ Downbar.prototype = {
 					var win;
 					while (e.hasMoreElements()) {
 						win = e.getNext();
-						win.db_populateDownloads();
+						win._dlbar_populateDownloads();
 					}
 				}
 				// xxx if subject is not null, (only one download was removed), do I want to remove it from the download statusbar?
@@ -171,12 +182,12 @@ Downbar.prototype = {
 	    	//case -1:
 			//case 0:
 			case 5:   // Queued
-	    		this.db_startDownload(aDownload);
+	    		this._dlbar_startDownload(aDownload);
 	    		return;  // setStateSpecific will already be called during insertNewDownload
 	    	break;
 	    		
 	    	case 1:
-	    		this.db_finishDownload(aDownload);
+	    		this._dlbar_finishDownload(aDownload);
 	    	break;
 	    }
 	    
@@ -185,7 +196,7 @@ Downbar.prototype = {
 		var win;
 		while (e.hasMoreElements()) {
 			win = e.getNext();
-			win.db_setStateSpecific("db_" + aDownload.id, aDownload.state);
+			win._dlbar_setStateSpecific("db_" + aDownload.id, aDownload.state);
 		}
 	},
 	onProgressChange: function(aWebProgress, aRequest, aCurSelfProgress, aMaxSelfProgress, aCurTotalProgress, aMaxTotalProgress, aDownload) {},
@@ -195,23 +206,23 @@ Downbar.prototype = {
     onSecurityChange: function(aWebProgress, aRequest, state, aDownload) {},
     
     
-    db_startDownload : function(aDownload) {
+    _dlbar_startDownload : function(aDownload) {
     	
 		var elmpath = aDownload.targetFile.path;
 		//var fixedelmpath = elmpath.replace(/\\/g, "\\\\");  // The \ and ' get messed up in the command if they are not fixed
 		//fixedelmpath = fixedelmpath.replace(/\'/g, "\\\'");
-		var db_fileext = elmpath.split(".").pop().toLowerCase();
+		var _dlbar_fileext = elmpath.split(".").pop().toLowerCase();
 	
-		var db_pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
-		var db_ignoreList = new Array ( );
+		var _dlbar_pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
+		var _dlbar_ignoreList = new Array ( );
 		
-		var ignoreRaw = db_pref.getCharPref("downbar.function.ignoreFiletypes");
+		var ignoreRaw = _dlbar_pref.getCharPref("downbar.function.ignoreFiletypes");
 		ignoreRaw = ignoreRaw.toLowerCase().replace(/\s/g,'');  // remove all whitespace
-		db_ignoreList = ignoreRaw.split(",");
+		_dlbar_ignoreList = ignoreRaw.split(",");
 		
 		// If it's on the ignore list, don't show it on the downbar
-		for (var i=0; i<=db_ignoreList.length; ++i) {
-				if (db_fileext == db_ignoreList[i])	
+		for (var i=0; i<=_dlbar_ignoreList.length; ++i) {
+				if (_dlbar_fileext == _dlbar_ignoreList[i])	
 					return;
 		}
 		
@@ -226,10 +237,10 @@ Downbar.prototype = {
 		var nsIIOService = Components.classes['@mozilla.org/network/io-service;1'].getService(Components.interfaces.nsIIOService);
 		var target = nsIIOService.newFileURI(aDownload.targetFile,null,null).spec;
 		
-		var db_dlmgrContractID = "@mozilla.org/download-manager;1";
-		var db_dlmgrIID = Components.interfaces.nsIDownloadManager;
-		db_gDownloadManager = Components.classes[db_dlmgrContractID].getService(db_dlmgrIID);
-		var dbase = db_gDownloadManager.DBConnection;
+		var _dlbar_dlmgrContractID = "@mozilla.org/download-manager;1";
+		var _dlbar_dlmgrIID = Components.interfaces.nsIDownloadManager;
+		_dlbar_gDownloadManager = Components.classes[_dlbar_dlmgrContractID].getService(_dlbar_dlmgrIID);
+		var dbase = _dlbar_gDownloadManager.DBConnection;
 		dbase.executeSimpleSQL("UPDATE moz_downloads SET DownbarShow=1 WHERE id=" + id);
 		
 		var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"].getService(Components.interfaces.nsIWindowMediator);
@@ -240,41 +251,41 @@ Downbar.prototype = {
 			win = e.getNext();
 			
 			// Add Download to download bar in each window, and start updates
-			win.db_insertNewDownload("db_" + id, target, name, source, state, startTime, referrer);
-			win.db_updateDLrepeat("db_" + aDownload.id);
+			win._dlbar_insertNewDownload("db_" + id, target, name, source, state, startTime, referrer);
+			win._dlbar_updateDLrepeat("db_" + aDownload.id);
 			
 			win.document.getElementById("downbar").hidden = false;
-			win.db_checkShouldShow();
-			win.db_startUpdateMini();
+			win._dlbar_checkShouldShow();
+			win._dlbar_startUpdateMini();
 		}
     },
     
-    db_finishDownload : function(dl) {
+    _dlbar_finishDownload : function(dl) {
     	
 		var elmpath = dl.targetFile.path;
 		//var fixedelmpath = elmpath.replace(/\\/g, "\\\\");  // The \ and ' get messed up in the command if they are not fixed
 		//fixedelmpath = fixedelmpath.replace(/\'/g, "\\\'");
-		var db_fileext = elmpath.split(".").pop().toLowerCase();
+		var _dlbar_fileext = elmpath.split(".").pop().toLowerCase();
 		
-		this.db_dlCompleteSound(db_fileext);
+		this._dlbar_dlCompleteSound(_dlbar_fileext);
 		
-		this.db_AntiVirusScan(elmpath, db_fileext);
+		this._dlbar_AntiVirusScan(elmpath, _dlbar_fileext);
 		
-		var db_pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
-		var clearTime = db_pref.getIntPref("downbar.function.timeToClear");
-		var clearRaw = db_pref.getCharPref("downbar.function.clearFiletypes");
-		var db_clearList = new Array ( );
+		var _dlbar_pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
+		var clearTime = _dlbar_pref.getIntPref("downbar.function.timeToClear");
+		var clearRaw = _dlbar_pref.getCharPref("downbar.function.clearFiletypes");
+		var _dlbar_clearList = new Array ( );
 		
 		clearRaw = clearRaw.toLowerCase().replace(/\s/g,'');  // remove all whitespace
-		db_clearList = clearRaw.split(",");
+		_dlbar_clearList = clearRaw.split(",");
 		
 		// check if it's on the list of autoclear
 		var autoClear = false;
-		if(db_clearList[0] == "all" | db_clearList[0] == "*")
+		if(_dlbar_clearList[0] == "all" | _dlbar_clearList[0] == "*")
 			autoClear = true;
 		else {
-			for (var i=0; i<=db_clearList.length; ++i) {
-				if (db_fileext == db_clearList[i])
+			for (var i=0; i<=_dlbar_clearList.length; ++i) {
+				if (_dlbar_fileext == _dlbar_clearList[i])
 					autoClear = true;
 			}
 		}
@@ -292,26 +303,26 @@ Downbar.prototype = {
 			//acs.logStringMessage(win.self._content.location.href);
 			
 			if(autoClear) {
-				win.db_startAutoClear("db_" + dl.id, clearTime*1000);
+				win._dlbar_startAutoClear("db_" + dl.id, clearTime*1000);
 			}
 			
-			win.db_startUpdateMini();
+			win._dlbar_startUpdateMini();
 		}
     	
     },
     
     // List of the recently cleared downloads so that I can undo clear
-    db_recentCleared : [],
+    _dlbar_recentCleared : [],
     
-    db_undoClearOne : function() {
+    _dlbar_undoClearOne : function() {
     	
-    	var DLid = this.db_recentCleared.pop();
+    	var DLid = this._dlbar_recentCleared.pop();
 		
 		if(DLid) {
-			var db_dlmgrContractID = "@mozilla.org/download-manager;1";
-			var db_dlmgrIID = Components.interfaces.nsIDownloadManager;
-			var db_gDownloadManager = Components.classes[db_dlmgrContractID].getService(db_dlmgrIID);
-			var dbase = db_gDownloadManager.DBConnection;
+			var _dlbar_dlmgrContractID = "@mozilla.org/download-manager;1";
+			var _dlbar_dlmgrIID = Components.interfaces.nsIDownloadManager;
+			var _dlbar_gDownloadManager = Components.classes[_dlbar_dlmgrContractID].getService(_dlbar_dlmgrIID);
+			var dbase = _dlbar_gDownloadManager.DBConnection;
 			dbase.executeSimpleSQL("UPDATE moz_downloads SET DownbarShow=1 WHERE id=" + DLid);
 			
 			try {
@@ -328,11 +339,11 @@ Downbar.prototype = {
 			
 				while (e.hasMoreElements()) {
 					win = e.getNext();
-					win.db_insertNewDownload("db_" + DLid, stmt.getString(0), stmt.getString(1), stmt.getString(2), 
+					win._dlbar_insertNewDownload("db_" + DLid, stmt.getString(0), stmt.getString(1), stmt.getString(2), 
 									 stmt.getInt32(3), stmt.getInt64(4), stmt.getString(5));
 					
-					win.db_checkShouldShow();
-					win.db_updateMini();
+					win._dlbar_checkShouldShow();
+					win._dlbar_updateMini();
 				}
 				
 				stmt.reset();
@@ -340,7 +351,7 @@ Downbar.prototype = {
 		}	
     },
     
-    db_clearAllFinished : function() {
+    _dlbar_clearAllFinished : function() {
     	
     	// Remove the finished download elements in each browser window
     	try {
@@ -363,25 +374,25 @@ Downbar.prototype = {
 					downbarelem.removeChild(winElem);
 				}
 				
-				win.db_checkShouldShow();
-				win.db_updateMini();
+				win._dlbar_checkShouldShow();
+				win._dlbar_updateMini();
 				
     		}
     		
     		// Add all these cleared ids to the recentCleared array
-    		this.db_recentCleared = this.db_recentCleared.concat(finishedIDs);
+    		this._dlbar_recentCleared = this._dlbar_recentCleared.concat(finishedIDs);
     		
     	} catch(e) {}
     	
     	// Fix the database
     	try {
-    		var db_dlmgrContractID = "@mozilla.org/download-manager;1";
-			var db_dlmgrIID = Components.interfaces.nsIDownloadManager;
-			db_gDownloadManager = Components.classes[db_dlmgrContractID].getService(db_dlmgrIID);
-			var dbase = db_gDownloadManager.DBConnection;
+    		var _dlbar_dlmgrContractID = "@mozilla.org/download-manager;1";
+			var _dlbar_dlmgrIID = Components.interfaces.nsIDownloadManager;
+			_dlbar_gDownloadManager = Components.classes[_dlbar_dlmgrContractID].getService(_dlbar_dlmgrIID);
+			var dbase = _dlbar_gDownloadManager.DBConnection;
 			
-	    	var db_pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
-	    	var keepHist = db_pref.getBoolPref('downbar.function.keepHistory');
+	    	var _dlbar_pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
+	    	var keepHist = _dlbar_pref.getBoolPref('downbar.function.keepHistory');
 			
 			if(keepHist) {
 				var simpleStmt = "UPDATE moz_downloads SET DownbarShow=0 WHERE DownbarShow=1 AND state=1";
@@ -398,7 +409,7 @@ Downbar.prototype = {
 				}
 				try {
 					while (stmt.executeStep()) {
-						db_gDownloadManager.removeDownload(stmt.getInt32(0));
+						_dlbar_gDownloadManager.removeDownload(stmt.getInt32(0));
 					}
 				}
 				finally {
@@ -409,13 +420,13 @@ Downbar.prototype = {
     		
     },
     
-	db_dlCompleteSound : function(fileExt) {
+	_dlbar_dlCompleteSound : function(fileExt) {
 	
-		var db_pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
+		var _dlbar_pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
 	
 		try {
-			var shouldSound = db_pref.getIntPref("downbar.function.soundOnComplete");  // 0:no sound, 1: default sound, 2: custom sound
-			var ignoreListRaw = db_pref.getCharPref("downbar.function.soundCompleteIgnore");
+			var shouldSound = _dlbar_pref.getIntPref("downbar.function.soundOnComplete");  // 0:no sound, 1: default sound, 2: custom sound
+			var ignoreListRaw = _dlbar_pref.getCharPref("downbar.function.soundCompleteIgnore");
 		} catch(e){}
 		
 		if(shouldSound == 0)
@@ -442,10 +453,9 @@ Downbar.prototype = {
 				soundLoc = "chrome://downbar/content/downbar_finished.wav";
 			
 			if(shouldSound == 2) {
-				var soundLoc = db_pref.getCharPref("downbar.function.soundCustomComplete");  //format of filesystem sound "file:///c:/sound1_final.wav"
+				var soundLoc = _dlbar_pref.getCharPref("downbar.function.soundCustomComplete");  //format of filesystem sound "file:///c:/sound1_final.wav"
 			}
 			
-		
 			soundURIformat = nsIIOService.newURI(soundLoc,null,null);
 			sound.play(soundURIformat);
 		} catch(e) {
@@ -454,18 +464,18 @@ Downbar.prototype = {
 		
 	},
 	
-	db_AntiVirusScan : function(filepath, db_fileext) {
+	_dlbar_AntiVirusScan : function(filepath, _dlbar_fileext) {
 		
 		//var acs = Components.classes["@mozilla.org/consoleservice;1"].getService(Components.interfaces.nsIConsoleService);
 		//acs.logStringMessage(filepath);
 		
-		var db_pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
-		var shouldScan = db_pref.getBoolPref("downbar.function.virusScan");
+		var _dlbar_pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
+		var shouldScan = _dlbar_pref.getBoolPref("downbar.function.virusScan");
 		if(shouldScan) {
 			
 			var dlPath = filepath;
 			try {
-				var defCharset = db_pref.getComplexValue("intl.charset.default", Components.interfaces.nsIPrefLocalizedString).data;
+				var defCharset = _dlbar_pref.getComplexValue("intl.charset.default", Components.interfaces.nsIPrefLocalizedString).data;
 				var uniConv = Components.classes['@mozilla.org/intl/scriptableunicodeconverter'].createInstance(Components.interfaces.nsIScriptableUnicodeConverter);
 				uniConv.charset = defCharset;
 				var convertedPath = uniConv.ConvertFromUnicode(dlPath);
@@ -473,21 +483,21 @@ Downbar.prototype = {
 			}
 			catch(e) {}
 			
-			var db_excludeList = new Array ( );
-			var excludeRaw = db_pref.getCharPref("downbar.function.virusExclude");
+			var _dlbar_excludeList = new Array ( );
+			var excludeRaw = _dlbar_pref.getCharPref("downbar.function.virusExclude");
 			excludeRaw = excludeRaw.toLowerCase().replace(/\s/g,'');  // remove all whitespace
-			db_excludeList = excludeRaw.split(",");
+			_dlbar_excludeList = excludeRaw.split(",");
 			
 			var excludeFiletype = false;
-			for (var i=0; i<=db_excludeList.length; ++i) {
-				if (db_fileext == db_excludeList[i])
+			for (var i=0; i<=_dlbar_excludeList.length; ++i) {
+				if (_dlbar_fileext == _dlbar_excludeList[i])
 					excludeFiletype = true;
 			}
 			
 			if(!excludeFiletype) {	
 				try {
-					var AVProgLoc = db_pref.getCharPref("downbar.function.virusLoc");
-					var AVArgs = db_pref.getCharPref("downbar.function.virusArgs");
+					var AVProgLoc = _dlbar_pref.getCharPref("downbar.function.virusLoc");
+					var AVArgs = _dlbar_pref.getCharPref("downbar.function.virusArgs");
 					var AVExecFile = Components.classes["@mozilla.org/file/local;1"].createInstance(Components.interfaces.nsILocalFile);
 					var process = Components.classes["@mozilla.org/process/util;1"].createInstance(Components.interfaces.nsIProcess);
 					
@@ -523,13 +533,13 @@ Downbar.prototype = {
 		
 	},
 	
-	db_trimHistory : function() {
+	_dlbar_trimHistory : function() {
 		
-		var db_pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
+		var _dlbar_pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
 		try {
-			var shouldTrim = db_pref.getBoolPref("downbar.function.trimHistory");
-			var trimOffset = db_pref.getIntPref("downbar.function.numToTrim");
-			var downloadRetention = db_pref.getIntPref("browser.download.manager.retention");
+			var shouldTrim = _dlbar_pref.getBoolPref("downbar.function.trimHistory");
+			var trimOffset = _dlbar_pref.getIntPref("downbar.function.numToTrim");
+			var downloadRetention = _dlbar_pref.getIntPref("browser.download.manager.retention");
 		} catch (e){}
 		
 		if(!shouldTrim)
@@ -537,10 +547,10 @@ Downbar.prototype = {
 		if(downloadRetention != 2) // Then it is clearing on close or on successful download and this will have no effect
 			return;
 	
-		const db_dlmgrContractID = "@mozilla.org/download-manager;1";
-		const db_dlmgrIID = Components.interfaces.nsIDownloadManager;
-		db_gDownloadManager = Components.classes[db_dlmgrContractID].getService(db_dlmgrIID);
-		var dbase = db_gDownloadManager.DBConnection;
+		const _dlbar_dlmgrContractID = "@mozilla.org/download-manager;1";
+		const _dlbar_dlmgrIID = Components.interfaces.nsIDownloadManager;
+		_dlbar_gDownloadManager = Components.classes[_dlbar_dlmgrContractID].getService(_dlbar_dlmgrIID);
+		var dbase = _dlbar_gDownloadManager.DBConnection;
 		
 		// Delete the all but the last xx rows from the database, if it is done, canceled, or failed
 		dbase.executeSimpleSQL("DELETE FROM moz_downloads " +
@@ -548,6 +558,15 @@ Downbar.prototype = {
 								"AND id NOT IN (select id from moz_downloads ORDER BY id DESC LIMIT " + trimOffset + ")");
 		
 	},
+/*	
+	var _dlbar_uninstallListen = {
+  		onUninstalling: function(addon) {
+  			var sound = Components.classes["@mozilla.org/sound;1"].createInstance(Components.interfaces.nsISound);
+			var nsIIOService = Components.classes['@mozilla.org/network/io-service;1'].getService(Components.interfaces.nsIIOService);
+			sound.play(nsIIOService.newURI("chrome://downbar/content/downbar_finished.wav",null,null));	
+  		}
+	},
+*/
 
 };
 
@@ -579,52 +598,50 @@ this.factory.constructor = aObj;
 }
 
 var gModule = {
-registerSelf: function (aComponentManager, aFileSpec, aLocation, aType)
-{
-aComponentManager.QueryInterface(CI.nsIComponentRegistrar);
-for (var key in this._objects) {
-var obj = this._objects[key];
-aComponentManager.registerFactoryLocation(obj.CID, obj.className,
-obj.contractID, aFileSpec, aLocation, aType);
-}
+	registerSelf: function (aComponentManager, aFileSpec, aLocation, aType) {
+		aComponentManager.QueryInterface(CI.nsIComponentRegistrar);
+		for (var key in this._objects) {
+			var obj = this._objects[key];
+			aComponentManager.registerFactoryLocation(obj.CID, obj.className,
+			obj.contractID, aFileSpec, aLocation, aType);
+		}
 
-// this can be deleted if you don't need to init on startup
-var catman = CC["@mozilla.org/categorymanager;1"].getService(CI.nsICategoryManager);
-catman.addCategoryEntry("xpcom-startup", MY_OBSERVER_NAME,
-Downbar.prototype.contractID, true, true);
-catman.addCategoryEntry("xpcom-shutdown", MY_OBSERVER_NAME,
-Downbar.prototype.contractID, true, true);
-},
+		// this can be deleted if you don't need to init on startup
+		var catman = CC["@mozilla.org/categorymanager;1"].getService(CI.nsICategoryManager);
+		catman.addCategoryEntry("xpcom-startup", MY_OBSERVER_NAME,Downbar.prototype.contractID, true, true);
+		//catman.addCategoryEntry("profile-after-change", MY_OBSERVER_NAME,Downbar.prototype.contractID, true, true);
+		catman.addCategoryEntry("xpcom-shutdown", MY_OBSERVER_NAME,Downbar.prototype.contractID, true, true);
+	},
 
-unregisterSelf: function(aCompMgr, aFileSpec, aLocation) {
-// this must be deleted if you delete the above code dealing with |catman|
-var catman = CC["@mozilla.org/categorymanager;1"].getService(CI.nsICategoryManager);
-catman.deleteCategoryEntry("xpcom-startup", MY_OBSERVER_NAME, true);
-// end of deleteable code
+	unregisterSelf: function(aCompMgr, aFileSpec, aLocation) {
+		// this must be deleted if you delete the above code dealing with |catman|
+		var catman = CC["@mozilla.org/categorymanager;1"].getService(CI.nsICategoryManager);
+		catman.deleteCategoryEntry("xpcom-startup", MY_OBSERVER_NAME, true);
+		// end of deleteable code
+		
+		aComponentManager.QueryInterface(CI.nsIComponentRegistrar);
+		for (var key in this._objects) {
+			var obj = this._objects[key];
+			aComponentManager.unregisterFactoryLocation(obj.CID, aFileSpec);
+		}
+	},
 
-aComponentManager.QueryInterface(CI.nsIComponentRegistrar);
-for (var key in this._objects) {
-var obj = this._objects[key];
-aComponentManager.unregisterFactoryLocation(obj.CID, aFileSpec);
-}
-},
+	getClassObject: function(aComponentManager, aCID, aIID) {
+		if (!aIID.equals(CI.nsIFactory)) throw CR.NS_ERROR_NOT_IMPLEMENTED;
+		
+		for (var key in this._objects) {
+			if (aCID.equals(this._objects[key].CID))
+			return this._objects[key].factory;
+		}
 
-getClassObject: function(aComponentManager, aCID, aIID) {
-if (!aIID.equals(CI.nsIFactory)) throw CR.NS_ERROR_NOT_IMPLEMENTED;
+		throw CR.NS_ERROR_NO_INTERFACE;
+	},
 
-for (var key in this._objects) {
-if (aCID.equals(this._objects[key].CID))
-return this._objects[key].factory;
-}
+	canUnload: function(aComponentManager) {
+		return true;
+	},
 
-throw CR.NS_ERROR_NO_INTERFACE;
-},
-
-canUnload: function(aComponentManager) {
-return true;
-},
-
-_objects: {} //FactoryHolder
+	_objects: {} //FactoryHolder
 };
 
 function NSGetModule(compMgr, fileSpec)
@@ -632,4 +649,12 @@ function NSGetModule(compMgr, fileSpec)
 for(var i in objects)
 gModule._objects[i] = new FactoryHolder(objects[i]);
 return gModule;
-} 
\ No newline at end of file
+}
+
+Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
+/*
+* XPCOMUtils.generateNSGetFactory was introduced in Mozilla 2 (Firefox 4).
+* XPCOMUtils.generateNSGetModule is for Mozilla 1.9.2 (Firefox 3.6).
+*/
+if (XPCOMUtils.generateNSGetFactory)
+    var NSGetFactory = XPCOMUtils.generateNSGetFactory(objects);
\ No newline at end of file
